@echo off
setlocal EnableDelayedExpansion

set "SOURCE_FILE=cb.asm"
set "OBJECT_FILE=cb.obj"
set "OUTPUT_FILE=cb.exe"
set "LISTING_FILE=cb.lst"
set "PDB_FILE=cb.pdb"

set "ML_PATH=C:\masm32\32\ml.exe"
set "LINK_PATH=C:\masm32\32\link.exe"

echo Building %SOURCE_FILE%...

rem Check if source file exists
if not exist "%SOURCE_FILE%" (
    echo Error: Source file %SOURCE_FILE% not found.
    goto error
)

rem Assemble
echo Assembling...
"%ML_PATH%" /c /coff /Zi /Fd "%PDB_FILE%" "%SOURCE_FILE%"
if %ERRORLEVEL% neq 0 (
    echo Assembly failed with error %ERRORLEVEL%
    echo See %LISTING_FILE% for details.
    goto error
)
echo Assembly successful.

rem Link
echo Linking...
"%LINK_PATH%" /entry:EntryPoint /nologo /DEBUG /SUBSYSTEM:CONSOLE /PDB:"%PDB_FILE%" "%OBJECT_FILE%" /OUT:"%OUTPUT_FILE%" C:\masm32\32\include\ntdll.lib
if %ERRORLEVEL% neq 0 (
    echo Linking failed with error %ERRORLEVEL%
    goto error
)
echo Linking successful.

rem Clean up
echo Cleaning up...
if exist "%OBJECT_FILE%" del "%OBJECT_FILE%"

echo Build successful! Output: %OUTPUT_FILE%
echo Listing file: %LISTING_FILE%
echo PDB file: %PDB_FILE%
goto end

:error
echo Build failed!

:end
endlocal
rem Removed 'pause' for automatic closing
exit /b %ERRORLEVEL%
